summaryrefslogtreecommitdiffstats
path: root/lib/public/comments/icommentsmanager.php
diff options
context:
space:
mode:
authorArthur Schiwon <blizzz@owncloud.com>2016-02-03 19:28:15 +0100
committerArthur Schiwon <blizzz@owncloud.com>2016-02-03 19:28:15 +0100
commit9370491822dd6aca5dfa0b2d15a3c34d4f035566 (patch)
treee1a56ea1475affc04f84c71ef62fb3fc0a2ef487 /lib/public/comments/icommentsmanager.php
parentc0322b3f983635ee3653a13837ae29e152e78803 (diff)
downloadnextcloud-server-9370491822dd6aca5dfa0b2d15a3c34d4f035566.tar.gz
nextcloud-server-9370491822dd6aca5dfa0b2d15a3c34d4f035566.zip
types shall always be plural
Diffstat (limited to 'lib/public/comments/icommentsmanager.php')
-rw-r--r--lib/public/comments/icommentsmanager.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/public/comments/icommentsmanager.php b/lib/public/comments/icommentsmanager.php
index f5b290bf8b2..46608ca8165 100644
--- a/lib/public/comments/icommentsmanager.php
+++ b/lib/public/comments/icommentsmanager.php
@@ -39,7 +39,7 @@ interface ICommentsManager {
*
* User interfaces shall show "Deleted user" as display name, if needed.
*/
- const DELETED_USER = 'deleted_user';
+ const DELETED_USER = 'deleted_users';
/**
* returns a comment instance
@@ -127,7 +127,7 @@ interface ICommentsManager {
* saved in the used data storage. Use save() after setting other fields
* of the comment (e.g. message or verb).
*
* @param string $actorType the actor type (e.g. 'user')
* @param string $actorId a user id
* @param string $objectType the object type the comment is attached to
* @param string $objectId the object id the comment is attached to
@@ -170,10 +170,10 @@ interface ICommentsManager {
* removes references to specific actor (e.g. on user delete) of a comment.
* The comment itself must not get lost/deleted.
*
* A 'user' type actor (type and id) should get replaced by the
* value of the DELETED_USER constant of this interface.
*
* @param string $actorType the actor type (e.g. 'user')
* @param string $actorId a user id
* @return boolean
* @since 9.0.0
@@ -183,7 +183,7 @@ interface ICommentsManager {
/**
* deletes all comments made of a specific object (e.g. on file delete)
*
- * @param string $objectType the object type (e.g. 'file')
+ * @param string $objectType the object type (e.g. 'files')
* @param string $objectId e.g. the file id
* @return boolean
* @since 9.0.0
@@ -127,7 +127,7 @@ interface ICommentsManager {
* of the comment (e.g. message or verb).
*
- * @param string $actorType the actor type (e.g. 'user')
+ * @param string $actorType the actor type (e.g. 'users')
* @param string $actorId a user id
* @param string $objectType the object type the comment is attached to
@@ -170,10 +170,10 @@ interface ICommentsManager {
* The comment itself must not get lost/deleted.
*
- * A 'user' type actor (type and id) should get replaced by the
+ * A 'users' type actor (type and id) should get replaced by the
* value of the DELETED_USER constant of this interface.
*
@@ -170,10 +170,10 @@ interface ICommentsManager {
* value of the DELETED_USER constant of this interface.
*
- * @param string $actorType the actor type (e.g. 'user')
+ * @param string $actorType the actor type (e.g. 'users')
* @param string $actorId a user id
* @return boolean